@@ -62,9 +62,10 @@ class SubmitJob(JobBase):
         """
         assert isinstance(tracker, TrackerBase), f'Not a TrackerBase: {tracker!r}'
         assert isinstance(tracker_jobs, TrackerJobsBase), f'Not a TrackerJobsBase: {tracker_jobs!r}'
-        tracker_jobs.signal.register('exception', self.exception)
-        tracker_jobs.signal.register('error', self.error)
-        tracker_jobs.signal.register('warning', self.warn)
+        for t in (tracker, tracker_jobs):
+            t.signal.register('warning', self.warn)
+            t.signal.register('error', self.error)
+            t.signal.register('exception', self.exception)
         self._tracker = tracker
         self._tracker_jobs = tracker_jobs
         self._submit_lock = asyncio.Lock()
@@ -127,8 +128,9 @@ class SubmitJob(JobBase):
             try:
                 self.signal.emit('uploading')
                 torrent_page_url = await self._tracker.upload(self._tracker_jobs)
-                self.send(torrent_page_url)
-                self.signal.emit('uploaded')
+                if torrent_page_url:
+                    self.send(torrent_page_url)
+                    self.signal.emit('uploaded')
             finally:
                 self.signal.emit('logging_out')
                 await self._tracker.logout()
