@@ -80,11 +80,11 @@ def limit_directory_size(path, max_total_size, min_age=None, max_age=None):
     """
     def size(filepaths):
         return sum(file_size(f) for f in filepaths
-                   if os.path.exists(f))
+                   if os.path.exists(f) and not os.path.islink(f))
 
     # This should return mtime if file system was mounted with noatime.
     def atime(filepath):
-        statinfo = os.stat(filepath)
+        statinfo = os.stat(filepath, follow_symlinks=False)
         return statinfo.st_atime
 
     # Remove oldest file until `path` size is small enough
@@ -112,6 +112,8 @@ def prune_empty(path, files=False, directories=True):
     :param bool files: Whether to prune empty files
     :param bool directories: Whether to prune empty directories
 
+    Dead symbolic links are removed after pruning files and directories.
+
     If `path` is not a directory, do nothing.
     """
     if not os.path.isdir(path):
@@ -123,25 +125,39 @@ def prune_empty(path, files=False, directories=True):
         else:
             raise RuntimeError(f'{path}: Failed to prune: {e}')
 
-    for dirpath, dirnames, filenames in os.walk(path, topdown=False):
-        if files:
+    # Prune empty files
+    if files:
+        for dirpath, dirnames, filenames in os.walk(path, topdown=False):
             for filename in filenames:
                 filepath = os.path.join(dirpath, filename)
                 try:
-                    if file_size(filepath) <= 0:
+                    if os.path.exists(filepath) and file_size(filepath) <= 0:
                         os.unlink(filepath)
                 except OSError as e:
                     raise_error(e, filepath)
 
-        if directories:
+    # Prune empty directories
+    if directories:
+        for dirpath, dirnames, filenames in os.walk(path, topdown=False):
             for dirname in dirnames:
                 subdirpath = os.path.join(dirpath, dirname)
                 try:
-                    if not os.listdir(subdirpath):
+                    if not os.path.islink(subdirpath) and not os.listdir(subdirpath):
                         os.rmdir(subdirpath)
                 except OSError as e:
                     raise_error(e, subdirpath)
 
+    # Prune dead links
+    for dirpath, dirnames, filenames in os.walk(path, topdown=False):
+        for filename in filenames:
+            filepath = os.path.join(dirpath, filename)
+            try:
+                if os.path.islink(filepath):
+                    if not os.path.exists(filepath):
+                        os.unlink(filepath)
+            except OSError as e:
+                raise_error(e, filepath)
+
     try:
         if directories and not os.listdir(path):
             os.rmdir(path)
@@ -233,11 +249,11 @@ def file_extension(path):
     :return: file extension
     :rtype: str
     """
-    path = str(path)
-    if '.' in path:
-        return re.sub(r'^.*\.([a-zA-Z0-9]{1,3})$', r'\1', path).lower()
-    else:
-        return ''
+    filename = os.path.basename(path)
+    match = re.search(r'\.([a-zA-Z0-9]{1,3})$', filename)
+    if match:
+        return match.group(1).lower()
+    return ''
 
 def strip_extension(path, only=()):
     """
@@ -303,7 +319,7 @@ def file_list(path, extensions=(), min_age=None, max_age=None):
         return not extensions or file_extension(filename).casefold() in extensions
 
     def age_ok(filepath, now=time.time()):
-        statinfo = os.stat(filepath)
+        statinfo = os.stat(filepath, follow_symlinks=False)
         age = round(now - statinfo.st_atime)
         return (min_age or age) <= age <= (max_age or age)
 
